# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wrappers for protocol buffer enum types."""

import enum


class View(enum.IntEnum):
    """
    A view presentation in basic format or detailed format.

    Attributes:
      BASIC (int): Basic information.
      DETAILED (int): Detailed information.
    """
    BASIC = 0
    DETAILED = 1


class Chart(object):
    class Resolution(enum.IntEnum):
        """
        The report resolution. The smallest resolution is one hour, but for
        larger reports (that is, 6 months), it is better to use higher values to
        save bandwidth. The user probably doesn't care about hourly trends when
        looking at a year's worth of data.

        Attributes:
          RESOLUTION_UNSPECIFIED (int): Not specified.
          RESOLUTION_ONE_HOUR (int): 1 hour.
          RESOLUTION_TWO_HOURS (int): 2 hours.
          RESOLUTION_SIX_HOURS (int): 6 hours.
          RESOLUTION_TWENTY_FOUR_HOURS (int): 24 hours.
        """
        RESOLUTION_UNSPECIFIED = 0
        RESOLUTION_ONE_HOUR = 1
        RESOLUTION_TWO_HOURS = 2
        RESOLUTION_SIX_HOURS = 3
        RESOLUTION_TWENTY_FOUR_HOURS = 4

    class Type(enum.IntEnum):
        """
        Type of chart data.

        Attributes:
          TYPE_UNSPECIFIED (int): Not specified.
          TYPE_ACTIVE_DEVICE_COUNTS (int): Count of active devices with a given property, that is, on a specific
          build.
          TYPE_UPDATE_STATE_COUNTS (int): Count of devices in a certain update stage, that is, downloading the
          update.
        """
        TYPE_UNSPECIFIED = 0
        TYPE_ACTIVE_DEVICE_COUNTS = 1
        TYPE_UPDATE_STATE_COUNTS = 2


class Config(object):
    class SpaceNeed(enum.IntEnum):
        """
        The space requirement in bytes.

        Attributes:
          SPACE_NEED_UNSPECIFIED (int): Not specified.
          ONE_HUNDRED_MB (int): 100 MB.
          ONE_HUNDRED_AND_FIFTY_MB (int): 150 MB.
          TWO_HUNDRED_AND_FIFTY_MB (int): 250 MB.
          FIVE_HUNDRED_MB (int): 500 MB.
        """
        SPACE_NEED_UNSPECIFIED = 0
        ONE_HUNDRED_MB = 1
        ONE_HUNDRED_AND_FIFTY_MB = 2
        TWO_HUNDRED_AND_FIFTY_MB = 3
        FIVE_HUNDRED_MB = 4

    class UrgencyMode(enum.IntEnum):
        """
        The upgrade urgency mode.

        Attributes:
          MODE_UNSPECIFIED (int): Not specified.
          RECOMMENDED (int): Recommend upgrade.  The user will be prompted to download and install
          the update.
          MANDATORY (int): Mandatory upgrade.  The update will download automatically but the user
          will be prompted to start the install.
          AUTOMATIC (int): Automatic upgrade.  The update will be downloaded and installed
          automatically.
        """
        MODE_UNSPECIFIED = 0
        RECOMMENDED = 2
        MANDATORY = 3
        AUTOMATIC = 4

    class WifiOnlyTime(enum.IntEnum):
        """
        Download will avoid mobile network for this period after update is
        available.

        Attributes:
          WIFI_ONLY_TIME_UNSPECIFIED (int): Not specified.
          NONE (int): Not blocked.
          TWO_HOURS (int): Two hour window.
          SIX_HOURS (int): Six hour window.
          TWENTY_FOUR_HOURS (int): Twenty four hour window.
          THREE_DAYS (int): Three days window.
          TEN_DAYS (int): Ten day window.
          NINETY_DAYS (int): Ninety day window.
          FOREVER (int): Forever window.
          ONE_HUNDRED_TWENTY_DAYS (int): One hundred and twenty days window.
        """
        WIFI_ONLY_TIME_UNSPECIFIED = 0
        NONE = 1
        TWO_HOURS = 2
        SIX_HOURS = 3
        TWENTY_FOUR_HOURS = 4
        THREE_DAYS = 5
        TEN_DAYS = 6
        NINETY_DAYS = 7
        FOREVER = 8
        ONE_HUNDRED_TWENTY_DAYS = 9

    class OffPeakUpdate(object):
        class CellularOperatorRestriction(enum.IntEnum):
            """
            For Off-peak OTAs, whether the off-peak window is only applicable for
            cellular operator or it can be applied to all networks.

            Attributes:
              OPERATOR_RESTRICTED_UNSPECIFIED (int): Not specified.
              CELLULAR_OPERATOR_RESTRICTED (int): The off-peak window is applicable for the cellular operator only.
              ALL_NETWORK_ALLOWED (int): The off-peak window is applicable for all networks.
            """
            OPERATOR_RESTRICTED_UNSPECIFIED = 0
            CELLULAR_OPERATOR_RESTRICTED = 1
            ALL_NETWORK_ALLOWED = 2

        class UpdateOffPeakDays(enum.IntEnum):
            """
            Number of days to try to download the update in the off-peak window.

            Attributes:
              OFF_PEAK_DAYS_UNSPECIFIED (int): Not specified.
              OFF_PEAK_UPDATE_ONE_DAY (int): 1 day.
              OFF_PEAK_UPDATE_THREE_DAYS (int): 3 days.
              OFF_PEAK_UPDATE_SEVEN_DAYS (int): 7 days.
              OFF_PEAK_UPDATE_FOURTEEN_DAYS (int): 14 days.
              OFF_PEAK_UPDATE_THIRTY_DAYS (int): 30 days.
            """
            OFF_PEAK_DAYS_UNSPECIFIED = 0
            OFF_PEAK_UPDATE_ONE_DAY = 1
            OFF_PEAK_UPDATE_THREE_DAYS = 2
            OFF_PEAK_UPDATE_SEVEN_DAYS = 3
            OFF_PEAK_UPDATE_FOURTEEN_DAYS = 4
            OFF_PEAK_UPDATE_THIRTY_DAYS = 5


class PackageConfig(object):
    class DownloadType(enum.IntEnum):
        """
        The type of download for OTA packages.

        Attributes:
          DOWNLOAD_TYPE_UNSPECIFIED (int): Not specified.
          NORMAL (int): Through Google servers.
          ZERO_COST (int): Through Google's specific VIP for zero-cost OTAs.
          CUSTOM (int): Through an external server. ``custom_download_url`` should be set along
          with this option.
        """
        DOWNLOAD_TYPE_UNSPECIFIED = 0
        NORMAL = 1
        ZERO_COST = 2
        CUSTOM = 3


class PackageDetails(object):
    class PackageUploadState(enum.IntEnum):
        """
        The state of package uploading.

        After the package file is fully transferred, a ``package`` will be
        created and the server will start processing the file to read package
        properties from it. The upload state will be set to ``IN_PROGRESS``
        until the processing is done. After processing, the upload state will be
        set to ``SUCCESS`` or ``FAILURE``.

        Attributes:
          PACKAGE_UPLOAD_STATE_UNSPECIFIED (int): Unspecified.
          SUCCESS (int): Upload succeeded.
          FAILURE (int): Upload failed. Most likely it's because the package is not valid (due to
          various reasons, for example, unable to unzip the file).
          IN_PROGRESS (int): The package is still being processed.
        """
        PACKAGE_UPLOAD_STATE_UNSPECIFIED = 0
        SUCCESS = 1
        FAILURE = 2
        IN_PROGRESS = 3


class PackageProperties(object):
    class PackageType(enum.IntEnum):
        """
        The type of package in this OTA.

        Attributes:
          PACKAGE_TYPE_UNSPECIFIED (int): Unspecified.
          FILE (int): File-based OTA.
          BLOCK (int): Block-based OTA.
          AB (int): A/B OTA.
        """
        PACKAGE_TYPE_UNSPECIFIED = 0
        FILE = 1
        BLOCK = 2
        AB = 3


class UserAccessLevel(object):
    class AccessLevel(enum.IntEnum):
        """
        The user can have different access levels to a deployment.

        Attributes:
          ACCESS_LEVEL_UNSPECIFIED (int): Not specified.
          READ_ONLY_ACCESS (int): The user can view but not modify the deployment.
          GROUPS_ONLY_ACCESS (int): The user can modify test groups but not the production group in this
          deployment.
          FULL_ACCESS (int): The user can modify both test groups and the production group in this
          deployment.
          NO_ACCESS (int): The user has no access to this deployment.
        """
        ACCESS_LEVEL_UNSPECIFIED = 0
        READ_ONLY_ACCESS = 1
        GROUPS_ONLY_ACCESS = 2
        FULL_ACCESS = 3
        NO_ACCESS = 4
